You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@river.apache.org by pe...@apache.org on 2013/01/02 06:21:08 UTC

svn commit: r1427655 [13/35] - in /river/jtsk/skunk/qa_refactor/trunk/qa: ./ doc/ src/com/sun/jini/qa/harness/ src/com/sun/jini/test/impl/discoverymanager/ src/com/sun/jini/test/impl/discoveryproviders/ src/com/sun/jini/test/impl/end2end/e2etest/ src/c...

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/joinmanager/RegisterStorm.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/joinmanager/RegisterStorm.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/joinmanager/RegisterStorm.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/joinmanager/RegisterStorm.java Wed Jan  2 05:20:52 2013
@@ -34,6 +34,7 @@ import net.jini.core.lookup.ServiceMatch
 
 import java.rmi.RemoteException;
 import java.util.ArrayList;
+import java.util.List;
 
 /**
  * This class verifies that the <code>JoinManager</code> utility class
@@ -75,12 +76,13 @@ public class RegisterStorm extends Abstr
 	/* Verify that the lookups were discovered */
 	logger.log(Level.FINE, 
 		   "verifying the lookup service(s) are discovered ...");
+        List<LocatorGroupsPair> lookupsStarted = getLookupServices().getLookupsStarted();
 	String[] groupsToDiscover =  toGroupsArray(lookupsStarted);
 	LookupDiscoveryManager ldm = getLookupDiscoveryManager();
 	mainListener.setLookupsToDiscover(lookupsStarted,
 					  toGroupsArray(lookupsStarted));
 	waitForDiscovery(mainListener);
-
+        int nServices = getLookupServices().getnServices();
 	logger.log(Level.FINE, 
 		   "registering " + nServices + " services ...");
 	int mod = 1;
@@ -116,8 +118,7 @@ public class RegisterStorm extends Abstr
 	logger.log(Level.FINE, 
 		   "querying the lookup service "
 		   +"to verify all service registrations ...");
-	ArrayList lusList = getLookupListSnapshot
-	    ("impl.joinmanager.RegisterStorm");
+	List lusList = getLookupListSnapshot("impl.joinmanager.RegisterStorm");
 	ServiceRegistrar reg = (ServiceRegistrar)lusList.get(0);
 	/* Verify nServices registered with lookup service 0 */
 	ServiceMatches matches = reg.lookup(template,

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/joinmanager/SetAddAttributesOrder.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/joinmanager/SetAddAttributesOrder.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/joinmanager/SetAddAttributesOrder.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/joinmanager/SetAddAttributesOrder.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.impl.joinmanag
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.AttributesUtil;
 
@@ -81,8 +82,8 @@ public class SetAddAttributesOrder exten
      *          method
      *   </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         /* From some given value, different from any of the current
 	 * attribute values, create a set of attributes with which to
 	 * initially replace all of the current attributes. 
@@ -142,8 +143,8 @@ public class SetAddAttributesOrder exten
             expectedAttrs[i] = new TestServiceIntAttr
          ((((AbstractBaseTest.TestServiceIntAttr)addAttrs[n]).val).intValue());
         }//end loop
-
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>
@@ -170,7 +171,7 @@ public class SetAddAttributesOrder exten
         logger.log(Level.FINE, "verifying attributes were "
                                         +"modified in the correct order on "
                                         +"each lookup service ...");
-        verifyPropagation(expectedAttrs,nSecsJoin);
+        verifyPropagation(expectedAttrs,getLookupServices().getnSecsJoin());
         AttributesUtil.displayAttributeSet(expectedAttrs,
 					   "expectedAttrs",
 					   Level.FINE);

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/joinmanager/TerminateSemantics.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/joinmanager/TerminateSemantics.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/AddLocatorsAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/AddLocatorsAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.locatordi
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -49,9 +50,10 @@ public class AddLocatorsAfterTerminate
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = ADD_LOCATORS;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/BadLocatorDiscoveryListener.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/BadLocatorDiscoveryListener.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/BadLocatorDiscoveryListener.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/BadLocatorDiscoveryListener.java Wed Jan  2 05:20:52 2013
@@ -63,18 +63,18 @@ public class BadLocatorDiscoveryListener
         /* Start the additional lookup services */
         startAddLookups();
         /* Verify discovery of the initial lookups */
-        doDiscovery(initLookupsToStart, mainListener);
+        doDiscovery(getLookupServices().getInitLookupsToStart(), mainListener);
         /*
          * Configure the listener's expected event state for the additional
          * lookup services
          */
         mainListener.clearAllEventInfo();
-        mainListener.setLookupsToDiscover(addLookupsToStart);
+        mainListener.setLookupsToDiscover(getLookupServices().getAddLookupsToStart());
         /*
          * Configure the lookup locator discovery utility to discover the
          * additional lookups
          */
-        LookupLocator[] locsToAdd = toLocatorArray(addLookupsToStart);
+        LookupLocator[] locsToAdd = toLocatorArray(getLookupServices().getAddLookupsToStart());
         locatorDiscovery.addLocators(locsToAdd);
         logger.log(Level.FINE, "added additional locators to "
                 + "lookup locator discovery --");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/DelayDiscoveryAfterDiscard.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/DelayDiscoveryAfterDiscard.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/DiscardAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/DiscardAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.locatordi
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -48,9 +49,10 @@ public class DiscardAfterTerminate exten
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = DISCARD;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetDiscoveredLocatorsAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetDiscoveredLocatorsAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetDiscoveredLocatorsAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetDiscoveredLocatorsAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.locatordi
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -49,9 +50,10 @@ public class GetDiscoveredLocatorsAfterT
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = GET_DISCOVERED_LOCATORS;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetLocatorsAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetLocatorsAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetLocatorsAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetLocatorsAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.locatordi
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -49,9 +50,10 @@ public class GetLocatorsAfterTerminate
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = GET_LOCATORS;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetRegistrarsAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetRegistrarsAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetRegistrarsAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetRegistrarsAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.locatordi
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -49,9 +50,10 @@ public class GetRegistrarsAfterTerminate
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = GET_REGISTRARS;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetUndiscoveredLocatorsAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetUndiscoveredLocatorsAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetUndiscoveredLocatorsAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/GetUndiscoveredLocatorsAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.locatordi
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -50,9 +51,10 @@ public class GetUndiscoveredLocatorsAfte
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = GET_UNDISCOVERED_LOCATORS;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/RemoveDiscoveryListenerAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/RemoveDiscoveryListenerAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/RemoveDiscoveryListenerAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/RemoveDiscoveryListenerAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.locatordi
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -49,9 +50,10 @@ public class RemoveDiscoveryListenerAfte
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = REMOVE_DISCOVERY_LISTENER;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/RemoveLocatorsAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/RemoveLocatorsAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/RemoveLocatorsAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/RemoveLocatorsAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.locatordi
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -49,9 +50,10 @@ public class RemoveLocatorsAfterTerminat
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = REMOVE_LOCATORS;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/SetLocatorsAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/SetLocatorsAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/SetLocatorsAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/SetLocatorsAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.locatordi
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -49,9 +50,10 @@ public class SetLocatorsAfterTerminate
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = SET_LOCATORS;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/UnicastDelay.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/UnicastDelay.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/UnicastDelay.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/UnicastDelay.java Wed Jan  2 05:20:52 2013
@@ -20,7 +20,8 @@ package com.sun.jini.test.impl.locatordi
 
 import com.sun.jini.config.Config;
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import java.net.DatagramPacket;
 import java.net.InetAddress;
 import java.net.MulticastSocket;
@@ -42,7 +43,7 @@ import net.jini.discovery.LookupLocatorD
  * .75 * initialUnicastDelayRange</code>.
  *
  */
-public class UnicastDelay extends QATest {
+public class UnicastDelay extends QATestEnvironment implements Test {
     
     private static final int DISCOVERYPORT = Constants.discoveryPort;
     private Configuration config;
@@ -80,9 +81,10 @@ public class UnicastDelay extends QATest
 	}
     }
     
-    public void setup(QAConfig qaConfig) throws Exception {
-	super.setup(qaConfig);
+    public Test construct(QAConfig qaConfig) throws Exception {
+	super.construct(qaConfig);
 	config = qaConfig.getConfig().getConfiguration();
+        return this;
     }
     
     public void run() throws Exception {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/AddGroupsAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/AddGroupsAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/AddGroupsAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/AddGroupsAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.lookupdis
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -49,9 +50,10 @@ public class AddGroupsAfterTerminate
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = ADD_GROUPS;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/DiscardAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/DiscardAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/DiscardAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/DiscardAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.lookupdis
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -48,9 +49,10 @@ public class DiscardAfterTerminate exten
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = DISCARD;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/GetGroupsAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/GetGroupsAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/GetGroupsAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/GetGroupsAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.lookupdis
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -49,9 +50,10 @@ public class GetGroupsAfterTerminate
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = GET_GROUPS;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/GetRegistrarsAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/GetRegistrarsAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/GetRegistrarsAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/GetRegistrarsAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.lookupdis
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -49,9 +50,10 @@ public class GetRegistrarsAfterTerminate
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = GET_REGISTRARS;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/MulticastRequestDelay.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/MulticastRequestDelay.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/MulticastRequestDelay.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/MulticastRequestDelay.java Wed Jan  2 05:20:52 2013
@@ -25,7 +25,8 @@ package com.sun.jini.test.impl.lookupdis
 
 import com.sun.jini.config.Config;
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import java.net.DatagramPacket;
 import java.net.InetAddress;
 import java.net.MulticastSocket;
@@ -47,7 +48,7 @@ import net.jini.discovery.LookupDiscover
  *
  * 
  */
-public class MulticastRequestDelay extends QATest {
+public class MulticastRequestDelay extends QATestEnvironment implements Test {
     private static final int DISCOVERYPORT = Constants.discoveryPort;
     private static final int NUMLD = 100;
     private static final InetAddress localHost;
@@ -157,9 +158,10 @@ public class MulticastRequestDelay exten
 	}
     }
     
-    public void setup(QAConfig qaconfig) throws Exception {
-	super.setup(qaconfig);
+    public Test construct(QAConfig qaconfig) throws Exception {
+	super.construct(qaconfig);
 	config = qaconfig.getConfig().getConfiguration();
+        return this;
     }
  
     public void tearDown() {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/RemoveDiscoveryListenerAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/RemoveDiscoveryListenerAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/RemoveDiscoveryListenerAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/RemoveDiscoveryListenerAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.lookupdis
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -49,9 +50,10 @@ public class RemoveDiscoveryListenerAfte
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = REMOVE_DISCOVERY_LISTENER;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/RemoveGroupsAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/RemoveGroupsAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/RemoveGroupsAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/RemoveGroupsAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.lookupdis
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -49,9 +50,10 @@ public class RemoveGroupsAfterTerminate
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = REMOVE_GROUPS;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/RestoreContextForTasks.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/RestoreContextForTasks.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/RestoreContextForTasks.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/RestoreContextForTasks.java Wed Jan  2 05:20:52 2013
@@ -26,13 +26,13 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import java.io.IOException;
 import net.jini.config.Configuration;
 import net.jini.discovery.DiscoveryGroupManagement;
 import net.jini.discovery.LookupDiscovery;
 import net.jini.loader.pref.PreferredClassLoader;
-
 /**
  * With respect to the current implementation of the
  * <code>LookupDiscovery</code> utility, this class verifies
@@ -108,14 +108,15 @@ public class RestoreContextForTasks exte
 	    return false;
 	}
     }
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	ClassLoader cl = PreferredClassLoader.newInstance(new URL[]
 	    {new URL("file://" + System.getProperty(QAHOMEPROP) + JARLOCATION)},
 	    this.getClass().getClassLoader(), null, false);
 	tp = (TestTaskProducer)
 	    Class.forName(CLASSNAME, true, cl).newInstance();
 	uld = tp.setup(sysConfig.getConfiguration());
+        return this;
     }
     /** (Copied from AbstractBaseTest). We cannot use that class for this test,
      *  because we only want a LookupDiscovery instance created from an
@@ -140,7 +141,7 @@ public class RestoreContextForTasks exte
      *  </ul>
      *  @throws com.sun.jini.qa.harness.TestException
      */
-    private void doDiscovery(ArrayList locGroupsListStartedLookups,
+    private void doDiscovery(List locGroupsListStartedLookups,
                                LookupDiscovery ld,
                                LookupListener listener,
                                String[] groupsToDiscover)
@@ -173,6 +174,7 @@ public class RestoreContextForTasks exte
     }//end doDiscovery
     
     public void run() throws Exception {
+        List initLookupsToStart = getLookupServices().getInitLookupsToStart();
 	doDiscovery(initLookupsToStart, uld, 
 		new LookupListener(), toGroupsArray(initLookupsToStart));
 	tp.run();

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/SetGroupsAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/SetGroupsAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/SetGroupsAfterTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/SetGroupsAfterTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.lookupdis
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the current implementation of the
@@ -49,9 +50,10 @@ public class SetGroupsAfterTerminate
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         methodType = SET_GROUPS;
+        return this;
     }
 }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/UnicastDelay.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/UnicastDelay.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/UnicastDelay.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/lookupdiscovery/UnicastDelay.java Wed Jan  2 05:20:52 2013
@@ -28,7 +28,8 @@ import com.sun.jini.discovery.Discovery;
 import com.sun.jini.discovery.EncodeIterator;
 import com.sun.jini.discovery.MulticastAnnouncement;
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import java.net.DatagramPacket;
 import java.net.InetAddress;
 import java.net.MulticastSocket;
@@ -54,7 +55,7 @@ import net.jini.discovery.LookupDiscover
  *
  * 
  */
-public class UnicastDelay extends QATest {
+public class UnicastDelay extends QATestEnvironment implements Test {
     private static final int DISCOVERYPORT = Constants.discoveryPort;
     private static final int NUMLD = 100;
     private Throwable failure = null;
@@ -90,9 +91,10 @@ public class UnicastDelay extends QATest
 	}
     }
     
-    public void setup(QAConfig qaconfig) throws Exception {
-	super.setup(qaconfig);
+    public Test construct(QAConfig qaconfig) throws Exception {
+	super.construct(qaconfig);
 	config = qaconfig.getConfig().getConfiguration();
+        return this;
     }
     
     public void run() throws Exception {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/AdminIFShutdownTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/AdminIFShutdownTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/MahaloImplReadyStateTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/MahaloImplReadyStateTest.java Wed Jan  2 05:20:52 2013
@@ -21,13 +21,14 @@ import java.util.logging.Level;
 import java.util.*;
 
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import net.jini.config.ConfigurationException;
 import com.sun.jini.start.ServiceStarter;
 import com.sun.jini.start.SharedGroup;
 import com.sun.jini.qa.harness.OverrideProvider;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.io.*;
 import java.rmi.*;
@@ -43,9 +44,10 @@ import net.jini.core.transaction.server.
  
 public class MahaloImplReadyStateTest extends TxnMgrTestBase {
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
-    }
+    // Appears to be an unnecessary override.
+//    public Test construct(QAConfig sysConfig) throws Exception {
+//	return super.construct(sysConfig);
+//    }
 
     public void run() throws Exception {
         

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/NestableServerTransactionCreatedToStringTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/NestableServerTransactionCreatedToStringTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/RandomStressTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/RandomStressTest.java Wed Jan  2 05:20:52 2013
@@ -29,6 +29,7 @@ import java.util.*;
 
 // Test harness specific classes
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.TxnManagerTest;
 
@@ -73,9 +74,10 @@ public class RandomStressTest extends Tx
     private Random random;
     private long seed = 0;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         this.parse();
+        return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/ServerTransactionEqualityTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/ServerTransactionEqualityTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrImplNullConfigEntries.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrImplNullConfigEntries.java Wed Jan  2 05:20:52 2013
@@ -20,13 +20,14 @@ package com.sun.jini.test.impl.mahalo;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import net.jini.config.ConfigurationException;
 import com.sun.jini.start.ServiceStarter;
 import com.sun.jini.start.SharedGroup;
 import com.sun.jini.qa.harness.OverrideProvider;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.io.*;
 import java.rmi.*;
@@ -39,7 +40,7 @@ import net.jini.core.transaction.server.
  * are not equal
  */
  
-public class TxnMgrImplNullConfigEntries extends QATest {
+public class TxnMgrImplNullConfigEntries extends QATestEnvironment implements Test {
 
     private static class OverrideGenerator implements OverrideProvider {
 
@@ -69,9 +70,10 @@ public class TxnMgrImplNullConfigEntries
 	}
     }
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
         sysConfig.addOverrideProvider(new OverrideGenerator());
+        return this;
     }
 
     public void run() throws Exception {
@@ -88,7 +90,7 @@ public class TxnMgrImplNullConfigEntries
 	for (int i=0; i < instances; i++) {
 	    try {
                 txn_mgr_proxy = 
-		    (TransactionManager)manager.startService(serviceName); 
+		    (TransactionManager)getManager().startService(serviceName); 
 	        throw new TestException( 
 		    "Started service with invalid configuration");
 	    } catch (Exception e) {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrImplNullRecoveredLocators.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrImplNullRecoveredLocators.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrImplNullRecoveredLocators.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrImplNullRecoveredLocators.java Wed Jan  2 05:20:52 2013
@@ -20,13 +20,14 @@ package com.sun.jini.test.impl.mahalo;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import net.jini.config.ConfigurationException;
 import com.sun.jini.start.ServiceStarter;
 import com.sun.jini.start.SharedGroup;
 import com.sun.jini.qa.harness.OverrideProvider;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.VMKiller;
 
 import java.io.*;
@@ -41,7 +42,7 @@ import net.jini.core.transaction.server.
  * are not equal
  */
  
-public class TxnMgrImplNullRecoveredLocators extends QATest {
+public class TxnMgrImplNullRecoveredLocators extends QATestEnvironment implements Test {
 
     private static class OverrideGenerator implements OverrideProvider {
 
@@ -81,9 +82,10 @@ public class TxnMgrImplNullRecoveredLoca
 	}
     }
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
         sysConfig.addOverrideProvider(new OverrideGenerator());
+        return this;
     }
 
     public void run() throws Exception {
@@ -94,8 +96,8 @@ public class TxnMgrImplNullRecoveredLoca
 	    "net.jini.core.transaction.server.TransactionManager";
 	try {
 	    txn_mgr_proxy = 
-		(TransactionManager)manager.startService(serviceName); 
-	    if (!manager.killVM(txn_mgr_proxy)) {
+		(TransactionManager)getManager().startService(serviceName); 
+	    if (!getManager().killVM(txn_mgr_proxy)) {
 		logger.log(Level.INFO, "Could not kill " + serviceName);
 	    }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrProxyEqualityTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrProxyEqualityTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrTestBase.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrTestBase.java Wed Jan  2 05:20:52 2013
@@ -26,6 +26,7 @@ import java.rmi.RemoteException;
 
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.TestBase;
 import net.jini.config.Configuration;
@@ -41,7 +42,7 @@ import net.jini.core.lease.LeaseDeniedEx
 
 
 
-public abstract class TxnMgrTestBase extends TestBase {
+public abstract class TxnMgrTestBase extends TestBase implements Test {
 
     protected void parse() throws Exception {
 	 super.parse();

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/AdminIFShutdownTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/AdminIFShutdownTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/EMSTestBase.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/EMSTestBase.java Wed Jan  2 05:20:52 2013
@@ -86,7 +86,7 @@ public abstract class EMSTestBase extend
 	        try {
 		    // Sleep one second between checks
 		    Thread.sleep(1000);
- 	            Thread.yield(); //Give someone else a chance
+// 	            Thread.yield(); //Give someone else a chance
 	        } catch (InterruptedException ie) { /* ignore */ }
 	    }
 	    events = tpl.getRemoteEvents(mr);
@@ -123,7 +123,7 @@ public abstract class EMSTestBase extend
                     + " has received " + received + " events.");
             }
 
-	    Thread.yield(); //Give someone else a chance
+//	    Thread.yield(); //Give someone else a chance
         }
     }
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/ExpiredRegRecovery.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/ExpiredRegRecovery.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/ExpiredRegRecovery.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/ExpiredRegRecovery.java Wed Jan  2 05:20:52 2013
@@ -83,7 +83,7 @@ public class ExpiredRegRecovery extends 
 		"Unsupported mailbox type requested" + mbType);
 	}
 	
-        Admin admin = manager.getAdmin(mb);
+        Admin admin = getManager().getAdmin(mb);
         if (! (admin instanceof ActivatableServiceStarterAdmin)) {
             throw new RemoteException("Service is not activatable");
         }

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/InterOpTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/InterOpTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxImplBadUnexportConfigEntries.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxImplBadUnexportConfigEntries.java Wed Jan  2 05:20:52 2013
@@ -20,13 +20,14 @@ package com.sun.jini.test.impl.mercury;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import net.jini.config.ConfigurationException;
 import com.sun.jini.start.ServiceStarter;
 import com.sun.jini.start.SharedGroup;
 import com.sun.jini.qa.harness.OverrideProvider;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.io.*;
 import java.rmi.*;
@@ -40,7 +41,7 @@ import net.jini.event.EventMailbox;
  * are not equal
  */
  
-public class MailboxImplBadUnexportConfigEntries extends QATest {
+public class MailboxImplBadUnexportConfigEntries extends QATestEnvironment implements Test {
 
     private  static class OverrideGenerator implements OverrideProvider {
 
@@ -70,9 +71,10 @@ public class MailboxImplBadUnexportConfi
 	}
     }
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
         sysConfig.addOverrideProvider(new OverrideGenerator());
+        return this;
     }
 
     public void run() throws Exception {
@@ -88,7 +90,7 @@ public class MailboxImplBadUnexportConfi
 	for (int i=0; i < instances; i++) {
 	    try {
                 mailbox_proxy = 
-		    (EventMailbox)manager.startService(serviceName); 
+		    (EventMailbox)getManager().startService(serviceName); 
 	        throw new TestException( 
 		    "Started service with invalid configuration");
 	    } catch (Exception e) {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxImplNullConfigEntries.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxImplNullConfigEntries.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxImplNullConfigEntries.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxImplNullConfigEntries.java Wed Jan  2 05:20:52 2013
@@ -20,13 +20,14 @@ package com.sun.jini.test.impl.mercury;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import net.jini.config.ConfigurationException;
 import com.sun.jini.start.ServiceStarter;
 import com.sun.jini.start.SharedGroup;
 import com.sun.jini.qa.harness.OverrideProvider;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.io.*;
 import java.rmi.*;
@@ -40,7 +41,7 @@ import net.jini.event.EventMailbox;
  * are not equal
  */
  
-public class MailboxImplNullConfigEntries extends QATest {
+public class MailboxImplNullConfigEntries extends QATestEnvironment implements Test {
 
     private  static class OverrideGenerator implements OverrideProvider {
 
@@ -70,9 +71,10 @@ public class MailboxImplNullConfigEntrie
 	}
     }
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
         sysConfig.addOverrideProvider(new OverrideGenerator());
+        return this;
     }
 
     public void run() throws Exception {
@@ -88,7 +90,7 @@ public class MailboxImplNullConfigEntrie
 	for (int i=0; i < instances; i++) {
 	    try {
                 mailbox_proxy = 
-		    (EventMailbox)manager.startService(serviceName); 
+		    (EventMailbox)getManager().startService(serviceName); 
 	        throw new TestException( 
 		    "Started service with invalid configuration");
 	    } catch (Exception e) {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxImplReadyStateTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxImplReadyStateTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxImplReadyStateTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxImplReadyStateTest.java Wed Jan  2 05:20:52 2013
@@ -21,13 +21,14 @@ import java.util.logging.Level;
 import java.util.*;
 
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import net.jini.config.ConfigurationException;
 import com.sun.jini.start.ServiceStarter;
 import com.sun.jini.start.SharedGroup;
 import com.sun.jini.qa.harness.OverrideProvider;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.io.*;
 import java.rmi.*;
@@ -43,8 +44,9 @@ import net.jini.event.EventMailbox;
  
 public class MailboxImplReadyStateTest extends MailboxTestBase {
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
+        return this;
     }
 
     public void run() throws Exception {
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/joinmanager/TerminateSemantics.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/joinmanager/TerminateSemantics.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.impl.joinmanager;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -62,17 +63,18 @@ public class TerminateSemantics extends 
      *          lease renewal manager
      *   </ul>
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         logger.log(Level.FINE, "creating a service ID join manager ...");
         joinMgrSrvcID = new JoinManager(testService,serviceAttrs,serviceID,
                                         null,null,
 					sysConfig.getConfiguration());
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>
      *  Terminates the join manager created in setup and verifies that
      *  an invocation of any of that join manager's public methods will
      *  result in an <code>IllegalStateException</code>.
      */
@@ -62,17 +63,18 @@ public class TerminateSemantics extends 
     /** Executes the current test by doing the following:
      * <p>
-     *  Terminates the join manager created in setup and verifies that
+     *  Terminates the join manager created in construct and verifies that
      *  an invocation of any of that join manager's public methods will
      *  result in an <code>IllegalStateException</code>.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/AddLocatorsAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/AddLocatorsAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/DelayDiscoveryAfterDiscard.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/DelayDiscoveryAfterDiscard.java Wed Jan  2 05:20:52 2013
@@ -19,6 +19,7 @@
 package com.sun.jini.test.impl.locatordiscovery;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.DiscoveryServiceUtil;
 import java.util.logging.Level;
@@ -58,20 +59,21 @@ public class DelayDiscoveryAfterDiscard 
     /** Performs actions necessary to prepare for execution of the 
      *  current test.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
 	firstWait = sysConfig.getLongConfigVal(
 	    "com.sun.jini.test.impl.locatordiscovery.discardDelayFirstWait",
 	    5000);
 	nextWait = sysConfig.getLongConfigVal(
 	    "com.sun.jini.test.impl.locatordiscovery.discard",
 	    30000);
-    }//end setup
+        return this;
+    }//end construct
     /** Executes the current test by doing the following:
      * <p><ul>
      *    <li> configures the lookup locator discovery utility to discover
      *         the set of locators whose elements are the locators of each
      *         lookup service that was started during setup
      *    <li> starts the unicast discovery process by adding a discovery
      *         listener to the lookup locator discovery utility
      *    <li> verifies that the lookup locator discovery utility under test
@@ -81,7 +83,7 @@ public class DelayDiscoveryAfterDiscard 
      */
     public void run() throws Exception {
         logger.log(Level.FINE, "run()");
-        doDiscovery(initLookupsToStart, mainListener);
+        doDiscovery(getLookupServices().getInitLookupsToStart(), mainListener);
 	logger.log(Level.FINE, "calling getRegistrars ... ");
         ServiceRegistrar[] regs = locatorDiscovery.getRegistrars();
 	// there should only be one here, but we'll discard all of them
@@ -58,20 +59,21 @@ public class DelayDiscoveryAfterDiscard 
      *    <li> configures the lookup locator discovery utility to discover
      *         the set of locators whose elements are the locators of each
-     *         lookup service that was started during setup
+     *         lookup service that was started during construct
      *    <li> starts the unicast discovery process by adding a discovery
      *         listener to the lookup locator discovery utility

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/DiscardAfterTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/locatordiscovery/DiscardAfterTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/AdminIFShutdownTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/AdminIFShutdownTest.java Wed Jan  2 05:20:52 2013
@@ -29,6 +29,7 @@ import java.util.List;
 import java.util.Arrays;
 
 import com.sun.jini.admin.DestroyAdmin;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.admin.Administrable;
 import net.jini.admin.JoinAdmin;
@@ -304,10 +305,11 @@ public class AdminIFShutdownTest extends
     }
 
     /**
      * Invoke parent's setup and parser
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -304,10 +305,11 @@ public class AdminIFShutdownTest extends
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      */

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/AdminIFTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/AdminIFTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/AdminIFTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/AdminIFTest.java Wed Jan  2 05:20:52 2013
@@ -29,6 +29,7 @@ import java.util.List;
 import java.util.Arrays;
 
 import com.sun.jini.admin.DestroyAdmin;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.admin.Administrable;
 import net.jini.admin.JoinAdmin;
@@ -219,12 +220,13 @@ public class AdminIFTest extends AdminIF
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -219,12 +220,13 @@ public class AdminIFTest extends AdminIF
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseExpireCancelTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseExpireCancelTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseExpireCancelTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseExpireCancelTest.java Wed Jan  2 05:20:52 2013
@@ -26,6 +26,7 @@ import com.sun.jini.qa.harness.TestExcep
 import java.rmi.RemoteException;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.core.lease.Lease;
 import net.jini.core.lease.UnknownLeaseException;
@@ -65,12 +66,13 @@ public class LeaseExpireCancelTest exten
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -65,12 +66,13 @@ public class LeaseExpireCancelTest exten
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseExpireRenewTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseExpireRenewTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseExpireRenewTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseExpireRenewTest.java Wed Jan  2 05:20:52 2013
@@ -26,6 +26,7 @@ import com.sun.jini.qa.harness.TestExcep
 import java.rmi.RemoteException;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.core.lease.Lease;
 import net.jini.core.lease.UnknownLeaseException;
@@ -64,10 +65,11 @@ public class LeaseExpireRenewTest extend
     }
 
     /**
      * Invoke parent's setup and parser
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -64,10 +65,11 @@ public class LeaseExpireRenewTest extend
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      */

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseMapTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseMapTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseMapTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseMapTest.java Wed Jan  2 05:20:52 2013
@@ -24,6 +24,7 @@ import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.core.lease.Lease;
 import net.jini.core.lease.LeaseMap;
@@ -153,13 +154,14 @@ public class LeaseMapTest extends TxnMgr
     }
 
     /**
      * Invoke parent's setup and invoke parser for this test
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 
     private void dumpLeaseMapException(LeaseMapException lme) {
@@ -153,13 +154,14 @@ public class LeaseMapTest extends TxnMgr
 
     /**
-     * Invoke parent's setup and invoke parser for this test
+     * Invoke parent's construct and invoke parser for this test
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/LeaseTest.java Wed Jan  2 05:20:52 2013
@@ -26,6 +26,7 @@ import com.sun.jini.qa.harness.TestExcep
 import java.rmi.RemoteException;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.core.lease.Lease;
 import net.jini.core.lease.UnknownLeaseException;
@@ -97,10 +98,11 @@ public class LeaseTest extends TxnMgrTes
     }
 
     /**
      * Invoke parent's setup and invoke parser for this test
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 }
@@ -97,10 +98,11 @@ public class LeaseTest extends TxnMgrTes
 
     /**
-     * Invoke parent's setup and invoke parser for this test
+     * Invoke parent's construct and invoke parser for this test
      */

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/MahaloImplReadyStateTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/MahaloImplReadyStateTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/NestableServerTransactionCreatedToStringTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/NestableServerTransactionCreatedToStringTest.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.constants.TimeConstants;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.core.lease.Lease;
 import net.jini.core.lease.LeaseDeniedException;
@@ -90,12 +91,13 @@ public class NestableServerTransactionCr
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -90,12 +91,13 @@ public class NestableServerTransactionCr
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/NestableTransactionCreatedToStringTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/NestableTransactionCreatedToStringTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/NestableTransactionCreatedToStringTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/NestableTransactionCreatedToStringTest.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.constants.TimeConstants;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.core.lease.Lease;
 import net.jini.core.lease.LeaseDeniedException;
@@ -108,12 +109,13 @@ public class NestableTransactionCreatedT
 }
 
     /**
      * Invoke parent's setup and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -108,12 +109,13 @@ public class NestableTransactionCreatedT
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/RandomStressTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/RandomStressTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/ServerTransactionEqualityTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/ServerTransactionEqualityTest.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.mahalo;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import java.rmi.MarshalledObject;
@@ -106,13 +107,14 @@ public class ServerTransactionEqualityTe
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 
     private static boolean checkEquality(Object a, Object b) {
@@ -106,13 +107,14 @@ public class ServerTransactionEqualityTe
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/ServerTransactionToStringTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/ServerTransactionToStringTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/ServerTransactionToStringTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/ServerTransactionToStringTest.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.constants.TimeConstants;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.core.transaction.server.ServerTransaction;
 import net.jini.core.transaction.server.TransactionManager;
@@ -56,12 +57,13 @@ public class ServerTransactionToStringTe
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -56,12 +57,13 @@ public class ServerTransactionToStringTe
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TransactionCreatedToStringTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TransactionCreatedToStringTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TransactionCreatedToStringTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TransactionCreatedToStringTest.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.constants.TimeConstants;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.core.lease.Lease;
 import net.jini.core.lease.LeaseDeniedException;
@@ -108,12 +109,13 @@ public class TransactionCreatedToStringT
 }
 
     /**
      * Invoke parent's setup and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -108,12 +109,13 @@ public class TransactionCreatedToStringT
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TransactionManagerCreatedToStringTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TransactionManagerCreatedToStringTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TransactionManagerCreatedToStringTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TransactionManagerCreatedToStringTest.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.constants.TimeConstants;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.core.lease.Lease;
 import net.jini.core.lease.LeaseDeniedException;
@@ -63,12 +64,13 @@ public class TransactionManagerCreatedTo
 }
 
     /**
      * Invoke parent's setup and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -63,12 +64,13 @@ public class TransactionManagerCreatedTo
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrImplNullConfigEntries.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrImplNullConfigEntries.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrProxyEqualityTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrProxyEqualityTest.java Wed Jan  2 05:20:52 2013
@@ -28,6 +28,7 @@ import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.core.lease.Lease;
 import net.jini.core.transaction.server.TransactionManager;
@@ -117,13 +118,14 @@ public class TxnMgrProxyEqualityTest ext
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 
     private static boolean proxiesEqual(Object a, Object b) {
@@ -117,13 +118,14 @@ public class TxnMgrProxyEqualityTest ext
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrTestBase.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mahalo/TxnMgrTestBase.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/AdminIFShutdownTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/AdminIFShutdownTest.java Wed Jan  2 05:20:52 2013
@@ -29,6 +29,7 @@ import java.util.List;
 import java.util.Arrays;
 
 import com.sun.jini.admin.DestroyAdmin;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.admin.Administrable;
 import net.jini.admin.JoinAdmin;
@@ -283,12 +284,13 @@ public class AdminIFShutdownTest extends
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -283,12 +284,13 @@ public class AdminIFShutdownTest extends
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/AdminIFTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/AdminIFTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/AdminIFTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/AdminIFTest.java Wed Jan  2 05:20:52 2013
@@ -29,6 +29,7 @@ import java.util.List;
 import java.util.Arrays;
 
 import com.sun.jini.admin.DestroyAdmin;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.admin.Administrable;
 import net.jini.admin.JoinAdmin;
@@ -213,12 +214,13 @@ public class AdminIFTest extends AdminIF
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -213,12 +214,13 @@ public class AdminIFTest extends AdminIF
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/BadEventCodebaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/BadEventCodebaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/BadEventCodebaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/BadEventCodebaseTest.java Wed Jan  2 05:20:52 2013
@@ -42,6 +42,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class BadEventCodebaseTest 
@@ -73,7 +74,7 @@ public class BadEventCodebaseTest 
 
 	// Get the mailbox service provided listener
 	RemoteEventListener mbRel = getPullMailboxListener(mr);
-	TestPullListener goodPullListener = TestUtils.createPullListener(manager);
+	TestPullListener goodPullListener = TestUtils.createPullListener(getManager());
         
        
         // Switch to pull interface -- should disable event listener
@@ -163,12 +164,13 @@ public class BadEventCodebaseTest 
 
     }
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -163,12 +164,13 @@ public class BadEventCodebaseTest 
     }
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/EMSTestBase.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/EMSTestBase.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/InterOpTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/InterOpTest.java Wed Jan  2 05:20:52 2013
@@ -36,6 +36,7 @@ import net.jini.space.JavaSpace;
 
 import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 public class InterOpTest extends EMSTestBase implements TimeConstants {
 
@@ -72,7 +73,7 @@ public class InterOpTest extends EMSTest
 	RemoteEventListener mbRel = getMailboxListener(mr);
 
 	logger.log(Level.INFO, "Getting our own listener");
-	TestListener listener = TestUtils.createListener(manager);
+	TestListener listener = TestUtils.createListener(getManager());
 
 	//Setup space to generate events
 	logger.log(Level.INFO, "Setting up space notifications");
@@ -131,12 +132,13 @@ public class InterOpTest extends EMSTest
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -131,12 +132,13 @@ public class InterOpTest extends EMSTest
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseExpireCancelTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseExpireCancelTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseExpireCancelTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseExpireCancelTest.java Wed Jan  2 05:20:52 2013
@@ -27,6 +27,7 @@ import java.rmi.RemoteException;
 import java.util.Date;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.EventMailbox;
 import net.jini.event.MailboxRegistration;
@@ -89,12 +90,13 @@ public class LeaseExpireCancelTest exten
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -89,12 +90,13 @@ public class LeaseExpireCancelTest exten
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseExpireRenewTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseExpireRenewTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseExpireRenewTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseExpireRenewTest.java Wed Jan  2 05:20:52 2013
@@ -27,6 +27,7 @@ import java.rmi.RemoteException;
 import java.util.Date;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.EventMailbox;
 import net.jini.event.MailboxRegistration;
@@ -87,10 +88,11 @@ public class LeaseExpireRenewTest extend
     }
 
     /**
      * Invoke parent's setup and parser
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -87,10 +88,11 @@ public class LeaseExpireRenewTest extend
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      */

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseMapTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseMapTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseMapTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseMapTest.java Wed Jan  2 05:20:52 2013
@@ -24,6 +24,7 @@ import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.EventMailbox;
 import net.jini.event.MailboxRegistration;
@@ -167,12 +168,13 @@ public class LeaseMapTest extends LeaseT
     }
 
     /**
      * Invoke parent's setup and invoke parser for this test
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 }
@@ -167,12 +168,13 @@ public class LeaseMapTest extends LeaseT
 
     /**
-     * Invoke parent's setup and invoke parser for this test
+     * Invoke parent's construct and invoke parser for this test
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/LeaseTest.java Wed Jan  2 05:20:52 2013
@@ -26,6 +26,7 @@ import com.sun.jini.qa.harness.TestExcep
 import java.rmi.RemoteException;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.EventMailbox;
 import net.jini.event.MailboxPullRegistration;
@@ -118,12 +119,13 @@ public class LeaseTest extends MailboxTe
     }
 
     /**
      * Invoke parent's setup and invoke parser for this test
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 }
@@ -118,12 +119,13 @@ public class LeaseTest extends MailboxTe
 
     /**
-     * Invoke parent's setup and invoke parser for this test
+     * Invoke parent's construct and invoke parser for this test
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/ListenerRecoveryTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/ListenerRecoveryTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/ListenerRecoveryTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/ListenerRecoveryTest.java Wed Jan  2 05:20:52 2013
@@ -38,6 +38,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 public class ListenerRecoveryTest 
     extends EMSTestBase implements TimeConstants 
@@ -73,7 +74,7 @@ public class ListenerRecoveryTest 
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	logger.log(Level.FINEST, 
 	    "Test generator class tree:" 
 	    + getClassLoaderTree(myGen.getClass().getClassLoader()));
@@ -85,7 +86,7 @@ public class ListenerRecoveryTest 
 	Lease tgl = evtReg.getLease();
 	checkLease(tgl, DURATION1); 
 
-	TestListener goodListener = TestUtils.createListener(manager);
+	TestListener goodListener = TestUtils.createListener(getManager());
 	int goodCount = 0;
 
 	// Generate some events 
@@ -137,12 +138,13 @@ public class ListenerRecoveryTest 
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -137,12 +138,13 @@ public class ListenerRecoveryTest 
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxImplBadUnexportConfigEntries.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxImplBadUnexportConfigEntries.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================